import 'package:flutter/material.dart';
import 'package:flutter_sound/flutter_sound.dart';
import 'package:audioplayers/audioplayers.dart';
import 'package:permission_handler/permission_handler.dart';

class SoundRecordPage extends StatefulWidget {
  @override
  _SoundRecordPageState createState() => _SoundRecordPageState();
}

class _SoundRecordPageState extends State<SoundRecordPage> {
  FlutterSoundRecorder? _soundRecorder;
  AudioPlayer? _audioPlayer;
  String? _audioFilePath;

  @override
  void initState() {
    super.initState();
    _soundRecorder = FlutterSoundRecorder();
    _audioPlayer = AudioPlayer();
    _requestPermissions();
  }

  // 请求麦克风权限
  void _requestPermissions() async {
    await Permission.microphone.request();
  }

  // 开始录音
  void _startRecording() async {
    final tempPath =
        '/data/user/0/com.example.flutter_app/cache/recorded_audio.aac'; // 可根据需要调整路径
    await _soundRecorder?.startRecorder(
      toFile: tempPath,
      codec: Codec.aacADTS,
    );
    setState(() {
      _audioFilePath = tempPath;
    });
  }

  // 停止录音
  void _stopRecording() async {
    await _soundRecorder?.stopRecorder();
  }

  // 播放录音
  void _playRecording() async {
    if (_audioFilePath != null) {
      await _audioPlayer?.play(DeviceFileSource(_audioFilePath!));
    }
  }

  @override
  void dispose() {
    _soundRecorder?.closeRecorder();
    _audioPlayer?.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: Text('录音与播放')),
      body: Center(
        child: GestureDetector(
          onTapDown: (details) {
            _startRecording(); // 按下时开始录音
          },
          onTapUp: (details) {
            _stopRecording(); // 抬起时停止录音并播放
            _playRecording(); // 播放录音
          },
          child: Container(
            padding: EdgeInsets.all(20),
            decoration: BoxDecoration(
              color: Colors.blue,
              shape: BoxShape.circle,
            ),
            child: Icon(
              Icons.mic,
              color: Colors.white,
              size: 50,
            ),
          ),
        ),
      ),
    );
  }
}
